==> jetspeed-2-2.2.2-source-release.zip: jetspeed-2-2.2.2/jetspeed-api/src/main/java/org/apache/jetspeed/om/page/PageSecurity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.om.page;

import java.util.List;

/**
 * <p>
 * Security
 * </p>
 * <p>
 * Used to define named collections of SecurityConstraint objects.
 *
 * </p>
 * @author <a href="mailto:rwatler@finali.com">Randy Watler</a>
 * @version $Id: PageSecurity.java 516448 2007-03-09 16:25:47Z ate $
 *
 */
public interface PageSecurity extends Document
{   
    String DOCUMENT_TYPE = "page.security";
    
    /**
     * <p>
     * getSecurityConstraintsDefs
     * </p>
     *
     * @return security constraints definitions of type SecurityConstraintsDef
     */
    List getSecurityConstraintsDefs();
    
    /**
     * <p>
     * newSecurityConstraintsDef
     * </p>
     *
     * @return a newly created SecurityConstraintsDef object for use in PageSecurity
     */
    SecurityConstraintsDef newSecurityConstraintsDef();

    /**
     * <p>
     * setSecurityConstraintsDefs
     * </p>
     *
     * @param defintions security constraints definitions
     */
    void setSecurityConstraintsDefs(List definitions);

    /**
     * <p>
     * getSecurityConstraintsDef
     * </p>
     *
     * @param name of security constraints definition to return
     * @return security constraints definition
     */
    SecurityConstraintsDef getSecurityConstraintsDef(String name);

    /**
     * <p>
     * getGlobalSecurityConstraintsRefs
     * </p>
     *
     * @return global security constraints references of element type String
     */
    List getGlobalSecurityConstraintsRefs();
    
    /**
     * <p>
     * setGlobalSecurityConstraintsRefs
     * </p>
     *
     * @param constraintsRefs global security constraints references
     */
    void setGlobalSecurityConstraintsRefs(List constraintsRefs);
}

==> jetspeed-2-2.3.1-source-release.zip: jetspeed-2-2.3.1/jetspeed-api/src/main/java/org/apache/jetspeed/om/page/PageSecurity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.om.page;

import java.util.List;

/**
 * <p>
 * Security
 * </p>
 * <p>
 * Used to define named collections of SecurityConstraint objects.
 *
 * </p>
 * @author <a href="mailto:rwatler@finali.com">Randy Watler</a>
 * @version $Id: PageSecurity.java 1576488 2014-03-11 20:05:43Z rwatler $
 *
 */
public interface PageSecurity extends Document
{   
    String DOCUMENT_TYPE = "page.security";
    
    /**
     * <p>
     * getSecurityConstraintsDefs
     * </p>
     *
     * @return security constraints definitions of type SecurityConstraintsDef
     */
    List<SecurityConstraintsDef> getSecurityConstraintsDefs();
    
    /**
     * <p>
     * newSecurityConstraintsDef
     * </p>
     *
     * @return a newly created SecurityConstraintsDef object for use in PageSecurity
     */
    SecurityConstraintsDef newSecurityConstraintsDef();

    /**
     * <p>
     * setSecurityConstraintsDefs
     * </p>
     *
     * @param definitions security constraints definitions
     */
    void setSecurityConstraintsDefs(List<SecurityConstraintsDef> definitions);

    /**
     * <p>
     * getSecurityConstraintsDef
     * </p>
     *
     * @param name of security constraints definition to return
     * @return security constraints definition
     */
    SecurityConstraintsDef getSecurityConstraintsDef(String name);

    /**
     * <p>
     * getGlobalSecurityConstraintsRefs
     * </p>
     *
     * @return global security constraints references of element type String
     */
    List<String> getGlobalSecurityConstraintsRefs();
    
    /**
     * <p>
     * setGlobalSecurityConstraintsRefs
     * </p>
     *
     * @param constraintsRefs global security constraints references
     */
    void setGlobalSecurityConstraintsRefs(List<String> constraintsRefs);
}
